import unittest

# Tests for main
# - Arg: filename
# - Arg: outputfile
# - Arg: watch
# - Render or watch

# Tests for Jekkish
# Init
# - These all get set properly, spliced properly, etc.
# load_variables
# - Prevents "content" from being in the YAML header
# make_file
# - command gets set properly. Maybe I should just handle this in init, too
